#contact-view header {
  zoom: 1;
  margin-bottom: 1.414em;
}
#contact-view header:before, #contact-view header:after {
  content: " ";
  display: block;
  height: 0;
  visibility: hidden;
}
#contact-view header:after {
  clear: both;
}
.contactPortrait {
  text-align: center;
  margin: 0 auto 0.7em auto;
  border-radius: 50%;
  width: 100%;
  max-width: 300px;
  min-height: 300px;
  background-repeat: no-repeat;
  background-size: 50%;
  background-position: center;
}
.contactPortrait:hover > img {
  transform: scale(1);
}
.contactPortrait > img {
  border-radius: 50%;
  vertical-align: middle;
  padding: 0.7em;
  border: 4px solid #f5f5f5;
}
@media (min-width: 480px) {
  .contactPortrait {
    float: left;
    shape-outside: circle(10.575em);
    margin: 0 1.2em 0.7em 0;
  }
}
.contactPortrait.gender-f {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB2aWV3Qm94PSIwIDAgMzEuMjU5IDMxLjI1OSIgc3R5bGU9ImVuYWJsZS1iYWNr\a\
Z3JvdW5kOm5ldyAwIDAgMzEuMjU5IDMxLjI1OTsiIHhtbDpzcGFjZT0icHJlc2VydmUiPgo8Zz4K\a\
CTxwYXRoIHN0eWxlPSJmaWxsOiMwMzAxMDQ7IiBkPSJNMjYuNjQ2LDE4LjQzNGMtMC41NjktMS4y\a\
NjUtMy41MzUtMi4zODktNC41NTctMi43NDRjLTEuNTg3LTMuNDc2LTAuNzI5LTcuODY1LTAuNzI5\a\
LTcuODY1ICAgYy0wLjI4MSwxLjI0Ny0wLjY0MSwxLjcyNS0wLjY0MSwxLjcyNWMtMC4yNzksMi4y\a\
NTYtMi4xMTksNC4xMTQtMi4xMTksNC4xMTRjLTAuMDMxLDAuNjA2LDAuMDQ1LDEuMTIxLDAuMTg4\a\
LDEuNTYgICBjLTIuODQsNC41OTEtNS4xNjQsMi4xODktNi4zMTEsMC4zMTZjMC4yMTktMC41MDUs\a\
MC4zNTItMS4xMTgsMC4zMTItMS44NzZjMCwwLTEuODQtMS44NTgtMi4xMjEtNC4xMTQgICBjMCww\a\
LTAuMzU3LTAuNDc4LTAuNjM3LTEuNzI1YzAsMCwwLjg1NCw0LjM3NC0wLjcyNCw3Ljg0OGMtMS4y\a\
MjIsMC41MjQtMi40NTIsMC44OTYtMi40NTIsMC44OTYgICBjLTEuMzI4LDAuNTExLTEuODkxLDEu\a\
Mjc2LTEuODkxLDEuMjc2Yy0xLjk2MywyLjkxMi0yLjE5Myw5LjM5OC0yLjE5Myw5LjM5OGMwLjAy\a\
NiwxLjQ4MiwwLjY2MiwxLjYzNCwwLjY2MiwxLjYzNCAgIGM0LjUyMywyLjAxNiwxMS42MDcsMi4z\a\
NzUsMTEuNjA3LDIuMzc1YzcuMjc4LDAuMTU0LDEyLjU3NC0yLjA2OCwxMi41NzQtMi4wNjhjMC43\a\
Ny0wLjQ4NiwwLjc5My0wLjg2NywwLjc5My0wLjg2NyAgIEMyOC45NDMsMjMuNjY3LDI2LjY0Niwx\a\
OC40MzQsMjYuNjQ2LDE4LjQzNHoiLz4KCTxwYXRoIHN0eWxlPSJmaWxsOiMwMzAxMDQ7IiBkPSJN\a\
MTguODMzLDQuOTljMC4wNzgsMC4yOTEsMC41NDgsMS43ODMsMi4xMiwyLjQ1NWMwLDAsMC4wNTgt\a\
MC42MTEsMC4yMjktMC42NjkgICBjMCwwLDAuMTkzLDAuMDk2LDAuMjUsMC4zMjVjMCwwLDAuNDEt\a\
My45Mi0xLjM3NS01LjM4M2wwLjAxLTAuMDIxYy0zLjcyNi0zLjI4Ny03Ljk0Mi0wLjc4Ni03Ljk0\a\
Mi0wLjc4NiAgIGMtMy4wOSwxLjk4OC0yLjIyNiw2LjI4NC0yLjIyNiw2LjI4NEMxNS43MSw3Ljc0\a\
NCwxOC43NDUsNS4wNzEsMTguODMzLDQuOTl6Ii8+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+\a\
CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+Cjwv\a\
Zz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4K\a\
PC9zdmc+\a\
");
}
.contactPortrait.gender-m {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB2aWV3Qm94PSIwIDAgNDg3LjY3OCA0ODcuNjc4IiBzdHlsZT0iZW5hYmxlLWJh\a\
Y2tncm91bmQ6bmV3IDAgMCA0ODcuNjc4IDQ4Ny42Nzg7IiB4bWw6c3BhY2U9InByZXNlcnZlIj4K\a\
PGc+Cgk8Zz4KCQk8cGF0aCBzdHlsZT0iZmlsbDojMDEwMDAyOyIgZD0iTTM3Ny45OTYsMjgyLjM0\a\
N2MtNTYuMjAxLTE4LjM1Ny03OS41NjMtNDEuMTg1LTc5LjU2My00MS4xODVsLTEuODgxLDEuNzkz\a\
ICAgIGMtMTYuNjksMTUuNzA5LTM1LjE0OSwyNC45NDQtNTEuOTY1LDI0Ljk0NEgyNDNjLTE2Ljgx\a\
NSwwLTM1LjI3NC05LjIzNS01MS45NjQtMjQuOTQ0bC0xLjg4Mi0xLjc5MyAgICBjMCwwLTIzLjM2\a\
LDIyLjgyNy03OS41NjIsNDEuMTg1Yy04Mi45NjQsMzAuOTkyLTU4LjA1MywxNTcuMTE5LTU4LjA3\a\
NywxNTguMDk2YzIuNjEzLDE0LjA0Nyw0LjEzNiwxOC44NzUsNS40NjMsMTkuNDE3ICAgIGM4My4z\a\
MTQsMzcuMDkxLDI5MC4zMTksMzcuMDkxLDM3My42MzQsMGMxLjMyNy0wLjU0MiwyLjg1LTUuMzcs\a\
NS40NjMtMTkuNDE3QzQzNi4wNTEsNDM5LjQ2Niw0NjEuMjk1LDMxMy44NCwzNzcuOTk2LDI4Mi4z\a\
NDd6Ii8+CgkJPHBhdGggc3R5bGU9ImZpbGw6IzAxMDAwMjsiIGQ9Ik0zMzAuOTI0LDEyMS40NDFs\a\
LTAuNjk2LTAuNzU1Yy00LjY2OC00LjI3NC00LjMwMy00LjAyOS00LjMwMy00LjAyOXM4LjE0Mi00\a\
MS4wODMsMS42MTMtNjAuNTExICAgIGMtMTAuMjUtMzEuMDI3LTcxLjQ3NS01MS44MjItODMuNzU1\a\
LTU0LjIzOWMwLjAwMi0wLjAyMy03LjQ2OS0xLjUxOC03Ljk0Ni0xLjUyMWMwLDAtOS42NTktMS45\a\
NTMtMjAuODU0LDIuOTMgICAgYy03LjI5MSwyLjgwNS00NS40MDgsMjAuMDktNTYuMjI3LDUyLjgz\a\
Yy02LjUyOCwxOS40MjgsMS42MTQsNjAuNTExLDEuNjE0LDYwLjUxMXMwLjM2NS0wLjI0NS00LjMw\a\
NCw0LjAyOWwtMC42OTUsMC43NTUgICAgYy0zLjE1OCwzLjU4Ni0yLjM3OCwxNC44MDYsMS4wNzQs\a\
MjYuNDc5YzMuMTI4LDExLjY5NSw3LjIwNSwxNC44MzgsOC4xODIsMTcuNTc3YzkuOTAzLDQ2LjQ5\a\
Nyw0NC4zMzgsODYuMTk3LDc5LjQyOSw4Ni4xOTcgICAgczY3LjcwNy0zOS43LDc3LjYxLTg2LjE5\a\
N2MwLjk3OC0yLjczOCw1LjA1NS01Ljg4Miw4LjE4My0xNy41NzdDMzMzLjMwMSwxMzYuMjQ2LDMz\a\
NC4xNzIsMTI0LjI1NiwzMzAuOTI0LDEyMS40NDF6Ii8+Cgk8L2c+CjwvZz4KPGc+CjwvZz4KPGc+\a\
CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+Cjwv\a\
Zz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4K\a\
PGc+CjwvZz4KPC9zdmc+\a\
");
}
.contactPortrait.gender- {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB3aWR0aD0iNDc2LjUxOHB4IiBoZWlnaHQ9IjQ3Ni41MThweCIgdmlld0JveD0i\a\
MCAwIDQ3Ni41MTggNDc2LjUxOCIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgNDc2\a\
LjUxOCA0NzYuNTE4OyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+CjxnPgoJPHBhdGggZD0iTTI3Ni42\a\
MTksMzguMTE1Yy0yLjA0Ni0zLjE1OC0yLjcwMy01LjI5Mi0yLjcwMy01LjI5MmwwLjk3NS0wLjg5\a\
N2MwLDAsMS44OTYsMC43ODgsNS4yMSwyLjE0NiAgIGMxLjU2NCwwLjYyNCwzLjQ3OSwxLjM5LDUu\a\
Njc0LDIuMjU0YzIuMTYyLDAuNzgzLDQuNTE1LDEuNjk2LDcuMDM3LDIuMzA4YzEuMjQyLDAuMzg1\a\
LDIuNTA3LDAuNzY4LDMuODE0LDAuOTE1ICAgYzAuNjU4LDAuMDg3LDEuMjg1LDAuMjY4LDEuOTM3\a\
LDAuMzg4YzAuNjQ2LDAuMDQ0LDEuMjk0LDAuMDY1LDEuOTM4LDAuMTQ3YzIuNjA1LDAuMzUsNSww\a\
LjA2Nyw3LjYyNi0wLjA3ICAgYzEuMjE4LTAuNDQ4LDIuNTcyLTAuNTc0LDMuODk3LTEuMTQ0YzEu\a\
MjE0LTAuNzE3LDIuODAxLTEuMTMzLDMuOTI4LTIuMDUyYzAuNTk3LTAuNDEsMS4yMTctMC44Mzcs\a\
MS44ODItMS4yNTkgICBjMC42OS0wLjM4OCwxLjQyNC0wLjY5NSwyLjE1Ny0xLjQ4OGw0LjY0LTMu\a\
ODk2YzAuMDQ0LTAuMDYtMC4yNzEsMC4zOTktMC4xMiwwLjE4NWwwLjAzMi0wLjAzM2wwLjA3OS0w\a\
LjA3bDAuMTUzLTAuMTMxICAgbDAuMzA1LTAuMjczbDAuNjEyLTAuNTQ3bDEuMjE3LTEuMDY3bDIu\a\
Mjk3LTIuMTc4YzEuNDQ0LTEuNDg4LDMuMjYxLTIuNjQ4LDQuNzE3LTQuMDgyYzEuNDM0LTEuNDg0\a\
LDMuMzYxLTIuMzkyLDQuODk0LTMuODMxICAgYzEuNjQtMS4yOTIsMy41NTctMi4yNiw1LjQwNi0z\a\
LjUxM2MzLjg4NS0xLjgyOCw4LjQyNS0zLjE4NSwxMi40OS0yLjYxNWMxLjAxOSwwLjEwOSwyLjAw\a\
OSwwLjI2OCwyLjk4MywwLjQ0OCAgIGMwLjk0MiwwLjI2MiwxLjgyNywwLjU4NiwyLjcwMywwLjkx\a\
NGMxLjc5NCwwLjU5MiwzLjMzOSwxLjQzOSw0Ljc5NSwyLjI3NmMyLjkwOSwxLjY4MSw1LjIyMSwz\a\
LjYyOCw3LjA2OSw1LjUxMSAgIGMxLjgzNywxLjg4OCwzLjIxOCwzLjcyNyw0LjIxMiw1LjMzYzEu\a\
MDQyLDEuNTY5LDEuNjQ0LDIuOTU1LDIuMDY4LDMuOTAyYzAuMzUxLDAuOTc0LDAuNTM2LDEuNDk5\a\
LDAuNTM2LDEuNDk5bC0wLjk3NCwwLjkwOCAgIGMwLDAtMi4wODktMC43MDYtNS4yOTctMi4wNDdj\a\
LTEuNTYzLTAuNjIzLTMuNDU5LTEuNDA1LTUuNjM1LTIuMjgxYy0yLjEwMS0wLjg2NS00LjQxMi0x\a\
LjgxNy02Ljg1My0yLjY0MyAgIGMtMS4yMTUtMC40NDktMi40NzItMC45MTQtMy43NDItMS4yMjFj\a\
LTAuNjQ1LTAuMTU4LTEuMjc5LTAuNDExLTEuOTI3LTAuNTk2Yy0wLjY0Ni0wLjEzMS0xLjI5LTAu\a\
Mjk2LTEuOTM4LTAuNTA5ICAgYy0yLjYyMS0wLjg1NC01LjMyOS0xLjY5Ni04LjY4Mi0yLjA0NmMt\a\
MS41NCwwLjIwMy0zLjM3OSwwLjEzNy00Ljk4MSwwLjgwNWMtMS41NDEsMC43ODItMy4zMTEsMS4z\a\
ODQtNC41NDgsMi43NzQgICBjLTEuMjQ3LDEuMzQtMi42NywyLjUxMi0zLjU0NCw0LjIxOWwtMS4y\a\
NzEsMi41NDRsLTAuNTg0LDEuMjgxbC0wLjI4NCwwLjYzNWwtMC4xNCwwLjMyOGwtMC4wNywwLjE0\a\
N2wtMC4wMzMsMC4wNzdsLTAuMDIyLDAuMDQ5ICAgYzAuMTI2LTAuMTg2LTAuMTk2LDAuMjk2LTAu\a\
MTc0LDAuMjY4bC0yLjUwMSw1LjUxNmMtMC44MjEsMS43NzktMi43MDQsMy43ODctNC4yNDEsNS41\a\
NTRjLTEuNTYsMS45MjYtMy42NDksMy4wMzItNS41MDksNC41NDIgICBjLTEuOTQ3LDEuMzY4LTQu\a\
MzI0LDIuMTU2LTYuNSwzLjE0NmMtNC42MzEsMS4zMjMtOS40NjksMS41Ni0xMy41NCwwLjQ3MWMt\a\
Mi4wNzktMC40NTktMy45OTItMS4wNjItNS42NzgtMS45MzcgICBjLTEuNzY1LTAuNzQ1LTMuMjg2\a\
LTEuNjc0LTQuNzItMi41NzJjLTIuODUtMS44ODctNS4xMDktMy44ODUtNi44OTQtNS44NDRDMjc4\a\
Ljk3Myw0MS41NzMsMjc3LjYyMiwzOS43MDIsMjc2LjYxOSwzOC4xMTV6ICAgIE00NzYuNTE4LDM1\a\
MS4wM3YxMTMuNkgwdi0xMTMuNmgzMi40NTlWMjIzLjQybDkxLjQ3LTY0LjE3N3Y2NC4xNzdsOTEu\a\
NDU2LTY0LjE3N3Y2NC4xNzdsOTEuNDc1LTY0LjE3N3YxMjYuMTQzaDMxLjU2ICAgbDE3LjE0LTIy\a\
My4xMzloNTIuMzEzbDE1LjAwMiwyMjMuMTM5aDM1LjE5NnY2NS42NTNoMTguNDQ2VjM1MS4wM3og\a\
TTE0OS4zNzUsMzAxLjk3NUg3Ny40NjF2NjYuMzg3aDcxLjkxNFYzMDEuOTc1eiAgICBNMjczLjI5\a\
MywzMDEuOTc1aC03MS45MTZ2NjYuMzg3aDcxLjkxNlYzMDEuOTc1eiBNMzk4Ljc2OCwzMDEuOTc1\a\
aC03MS45MTR2NjYuMzg3aDcxLjkxNFYzMDEuOTc1eiIvPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+\a\
CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+Cjxn\a\
Pgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8\a\
L2c+Cjwvc3ZnPg==\a\
");
}
.contactInfos {
  width: auto;
}
.contactFolderContactsListig {
  zoom: 1;
  min-height: 400px;
}
.contactFolderContactsListig:before, .contactFolderContactsListig:after {
  content: " ";
  display: block;
  height: 0;
  visibility: hidden;
}
.contactFolderContactsListig:after {
  clear: both;
}
.contactPrivateInfo {
  width: auto;
}
.private-address {
  font-size: 1.2rem;
  font-weight: normal;
}
.contactFolderLoadMoreContacts {
  display: inline-block;
  min-height: 1em;
  border: 0;
  vertical-align: baseline;
  margin: 0 0.5em 1.414em 0;
  padding: 0.7em 1.2em;
  text-transform: none;
  text-shadow: none;
  font-weight: normal;
  font-size: 1em;
  line-height: 1.5em;
  font-style: normal;
  text-align: center;
  text-decoration: none;
  border-radius: 2px;
  box-shadow: none;
  user-select: none;
  text-decoration: none;
  color: #444;
  cursor: pointer;
  color: #efefef;
  background: #2980b9;
  text-align: center;
  margin: 0 auto;
  display: block;
}
.contactFolderLoadMoreContacts:hover {
  text-decoration: none;
  color: #444;
}
.contactFolderLoadMoreContacts:visited {
  color: #444;
}
.contactFolderLoadMoreContacts:visited:hover {
  color: #444;
}
.contactFolderLoadMoreContacts:hover, .contactFolderLoadMoreContacts:focus {
  background-color: #20638f;
  color: #efefef;
}
.contactFolderLoadMoreContacts:active {
  outline: none;
  background-color: #164666;
  color: #efefef;
}
.contactFolderLoadMoreContacts:visited {
  color: #efefef;
}
.contactFolderLoadMoreContacts:visited:hover {
  color: #efefef;
}
@media (min-width: 480px) {
  .contactFolderLoadMoreContacts {
    max-width: 30%;
  }
}
#contact-folder-view .letters {
  display: inline-block;
  width: 100%;
  margin: 0;
  padding: 0;
}
#contact-folder-view .letter.withContent {
  display: inline-block;
  min-height: 1em;
  border: 0;
  vertical-align: baseline;
  margin: 0 0.5em 1.414em 0;
  padding: 0.7em 1.2em;
  text-transform: none;
  text-shadow: none;
  font-weight: normal;
  font-size: 1em;
  line-height: 1.5em;
  font-style: normal;
  text-align: center;
  text-decoration: none;
  border-radius: 2px;
  box-shadow: none;
  user-select: none;
  text-decoration: none;
  color: #444;
  cursor: pointer;
  color: #efefef;
  background: #010004;
  display: inline;
  margin: 0;
  padding: 0;
  border: none;
  border-radius: 0;
  position: relative;
  width: 3.7037%;
  float: left;
  padding: 0.7em 0;
  text-align: center;
}
#contact-folder-view .letter.withContent:hover {
  text-decoration: none;
  color: #444;
}
#contact-folder-view .letter.withContent:visited {
  color: #444;
}
#contact-folder-view .letter.withContent:visited:hover {
  color: #444;
}
#contact-folder-view .letter.withContent:hover,
#contact-folder-view .letter.withContent:focus {
  background-color: black;
  color: #efefef;
}
#contact-folder-view .letter.withContent:active {
  outline: none;
  background-color: black;
  color: #efefef;
}
#contact-folder-view .letter.withContent:visited {
  color: #efefef;
}
#contact-folder-view .letter.withContent:visited:hover {
  color: #efefef;
}
#contact-folder-view .letter.withContent:hover,
#contact-folder-view .letter.withContent:focus,
#contact-folder-view .letter.withContent:active,
#contact-folder-view .letter.withContent.active {
  color: #efefef;
  background-color: #DA210E;
  border: none;
}
#contact-folder-view .letter.withContent:hover {
  transform: scale(1.2);
  z-index: 1;
}
#contact-folder-view .letter.withContent:first-child {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}
#contact-folder-view .letter.withContent:last-child {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}
#contact-folder-view .letter:not(.withContent):not(.active) {
  display: inline-block;
  min-height: 1em;
  border: 0;
  vertical-align: baseline;
  margin: 0 0.5em 1.414em 0;
  padding: 0.7em 1.2em;
  text-transform: none;
  text-shadow: none;
  font-weight: normal;
  font-size: 1em;
  line-height: 1.5em;
  font-style: normal;
  text-align: center;
  text-decoration: none;
  border-radius: 2px;
  box-shadow: none;
  user-select: none;
  text-decoration: none;
  color: #444;
  pointer-events: none;
  cursor: default;
  color: #e6e6e6;
  background: #f5f5f5;
  display: inline;
  margin: 0;
  padding: 0;
  border: none;
  border-radius: 0;
  position: relative;
  width: 3.7037%;
  float: left;
  padding: 0.7em 0;
  text-align: center;
}
#contact-folder-view .letter:not(.withContent):not(.active):hover {
  text-decoration: none;
  color: #444;
}
#contact-folder-view .letter:not(.withContent):not(.active):visited {
  color: #444;
}
#contact-folder-view .letter:not(.withContent):not(.active):visited:hover {
  color: #444;
}
#contact-folder-view .letter:not(.withContent):not(.active):hover,
#contact-folder-view .letter:not(.withContent):not(.active):focus,
#contact-folder-view .letter:not(.withContent):not(.active):active,
#contact-folder-view .letter:not(.withContent):not(.active).active {
  color: #efefef;
  background-color: #DA210E;
  border: none;
}
#contact-folder-view .letter:not(.withContent):not(.active):hover {
  transform: scale(1.2);
  z-index: 1;
}
#contact-folder-view .letter:not(.withContent):not(.active):first-child {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}
#contact-folder-view .letter:not(.withContent):not(.active):last-child {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}
#contact-folder-view .letter.active:not(.withContent) {
  display: inline-block;
  min-height: 1em;
  border: 0;
  vertical-align: baseline;
  margin: 0 0.5em 1.414em 0;
  padding: 0.7em 1.2em;
  text-transform: none;
  text-shadow: none;
  font-weight: normal;
  font-size: 1em;
  line-height: 1.5em;
  font-style: normal;
  text-align: center;
  text-decoration: none;
  border-radius: 2px;
  box-shadow: none;
  user-select: none;
  text-decoration: none;
  color: #444;
  cursor: pointer;
  color: #efefef;
  background: #010004;
  display: inline;
  margin: 0;
  padding: 0;
  border: none;
  border-radius: 0;
  position: relative;
  width: 3.7037%;
  float: left;
  padding: 0.7em 0;
  text-align: center;
}
#contact-folder-view .letter.active:not(.withContent):hover {
  text-decoration: none;
  color: #444;
}
#contact-folder-view .letter.active:not(.withContent):visited {
  color: #444;
}
#contact-folder-view .letter.active:not(.withContent):visited:hover {
  color: #444;
}
#contact-folder-view .letter.active:not(.withContent):hover,
#contact-folder-view .letter.active:not(.withContent):focus {
  background-color: black;
  color: #efefef;
}
#contact-folder-view .letter.active:not(.withContent):active {
  outline: none;
  background-color: black;
  color: #efefef;
}
#contact-folder-view .letter.active:not(.withContent):visited {
  color: #efefef;
}
#contact-folder-view .letter.active:not(.withContent):visited:hover {
  color: #efefef;
}
#contact-folder-view .letter.active:not(.withContent):hover,
#contact-folder-view .letter.active:not(.withContent):focus,
#contact-folder-view .letter.active:not(.withContent):active,
#contact-folder-view .letter.active:not(.withContent).active {
  color: #efefef;
  background-color: #DA210E;
  border: none;
}
#contact-folder-view .letter.active:not(.withContent):hover {
  transform: scale(1.2);
  z-index: 1;
}
#contact-folder-view .letter.active:not(.withContent):first-child {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}
#contact-folder-view .letter.active:not(.withContent):last-child {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}
#contactFolderSearchGadget {
  min-width: 0;
  width: 100%;
}
.contact-search-section {
  zoom: 1;
  width: 100%;
  max-width: 1200px;
  margin: 0 auto;
  display: block;
  position: relative;
  margin-bottom: 1.414em;
}
.contact-search-section:before, .contact-search-section:after {
  content: " ";
  display: block;
  height: 0;
  visibility: hidden;
}
.contact-search-section:after {
  clear: both;
}
.contactFolderAlphabeticalSearch {
  margin-left: -100%;
  position: relative;
  float: left;
  left: 100%;
  display: none;
}
@media print {
  .contactFolderAlphabeticalSearch {
    float: none;
    position: static;
    left: 0;
    margin: 0 !important;
  }
}
@media (min-width: 480px) {
  .contactFolderAlphabeticalSearch {
    width: 100%;
    display: block;
  }
}
@media (min-width: 800px) {
  .contactFolderAlphabeticalSearch {
    width: 72.37937%;
  }
}
.contactFolderSearchSlot {
  position: relative;
  float: left;
  left: 100%;
  margin-left: -100%;
  width: 100%;
}
@media print {
  .contactFolderSearchSlot {
    float: none;
    position: static;
    left: 0;
    margin: 0 !important;
  }
}
@media (min-width: 800px) {
  .contactFolderSearchSlot {
    margin-left: -26.12313%;
    width: 26.12313%;
  }
}

.has-sidebar-column .contactFolderAlphabeticalSearch,
.has-navigation-column .contactFolderAlphabeticalSearch {
  display: none;
}
@media (min-width: 800px) {
  .has-sidebar-column .contactFolderSearchSlot,
  .has-navigation-column .contactFolderSearchSlot {
    margin-left: -100%;
    width: 100%;
  }
}
.has-sidebar-column .contactSummary, .has-navigation-column .contactSummary {
  width: 100%;
  float: left;
}
@media (min-width: 480px) {
  .has-sidebar-column .contactSummary, .has-navigation-column .contactSummary {
    width: 100%;
    margin-right: 1.5%;
  }
  .has-sidebar-column .contactSummary:nth-child(1n+1),
  .has-navigation-column .contactSummary:nth-child(1n+1) {
    margin-right: 0;
  }
}
@media (min-width: 1024px) {
  .has-sidebar-column .contactSummary, .has-navigation-column .contactSummary {
    width: 49.25%;
    margin-right: 1.5%;
  }
  .has-sidebar-column .contactSummary:nth-child(1n+1),
  .has-navigation-column .contactSummary:nth-child(1n+1) {
    margin-right: 1.5%;
  }
  .has-sidebar-column .contactSummary:nth-child(2n+2),
  .has-navigation-column .contactSummary:nth-child(2n+2) {
    margin-right: 0;
  }
}
@media print {
  .has-sidebar-column .contactSummary, .has-navigation-column .contactSummary {
    width: 100% !important;
    margin-right: 0 !important;
  }
}
.contactSummary {
  zoom: 1;
  width: 100%;
  float: left;
  padding: 0.7em 1.2em;
  border: 1px solid #f5f5f5;
  box-shadow: 2px 2px 4px rgba(0, 0, 0, 0.1);
  position: relative;
  margin-bottom: 1.414em;
}
.contactSummary:before, .contactSummary:after {
  content: " ";
  display: block;
  height: 0;
  visibility: hidden;
}
.contactSummary:after {
  clear: both;
}
@media (min-width: 480px) {
  .contactSummary {
    width: 49.25%;
    margin-right: 1.5%;
  }
  .contactSummary:nth-child(2n+2) {
    margin-right: 0;
  }
}
@media (min-width: 1024px) {
  .contactSummary {
    width: 32.33333%;
    margin-right: 1.5%;
  }
  .contactSummary:nth-child(2n+2) {
    margin-right: 1.5%;
  }
  .contactSummary:nth-child(3n+3) {
    margin-right: 0;
  }
}
@media print {
  .contactSummary {
    width: 100% !important;
    margin-right: 0 !important;
  }
}
@media (min-width: 480px) {
  .contactSummary {
    min-height: 635px;
  }
}
.contactSummary .title {
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
}
.contactFolderContactsListig {
  margin-bottom: 1.414em;
}
.download-vcard {
  position: absolute;
  top: 0.7em;
  right: 1.2em;
  z-index: 1;
}
.contactImage {
  display: block;
  text-align: center;
  margin: 0 auto 1.414em auto;
  border-radius: 50%;
  max-width: 300px;
  height: 100%;
  background-repeat: no-repeat;
  background-size: 50%;
  background-position: center;
}
.contactImage:hover > img {
  transform: scale(1.05);
}
.contactImage > img {
  border-radius: 50%;
  vertical-align: middle;
  padding: 0.7em;
  border: 4px solid #f5f5f5;
  transition: transform 0.25s ease-out, box-shadow 0.25s ease-out;
}
.contactImage.gender-f {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB2aWV3Qm94PSIwIDAgMzEuMjU5IDMxLjI1OSIgc3R5bGU9ImVuYWJsZS1iYWNr\a\
Z3JvdW5kOm5ldyAwIDAgMzEuMjU5IDMxLjI1OTsiIHhtbDpzcGFjZT0icHJlc2VydmUiPgo8Zz4K\a\
CTxwYXRoIHN0eWxlPSJmaWxsOiMwMzAxMDQ7IiBkPSJNMjYuNjQ2LDE4LjQzNGMtMC41NjktMS4y\a\
NjUtMy41MzUtMi4zODktNC41NTctMi43NDRjLTEuNTg3LTMuNDc2LTAuNzI5LTcuODY1LTAuNzI5\a\
LTcuODY1ICAgYy0wLjI4MSwxLjI0Ny0wLjY0MSwxLjcyNS0wLjY0MSwxLjcyNWMtMC4yNzksMi4y\a\
NTYtMi4xMTksNC4xMTQtMi4xMTksNC4xMTRjLTAuMDMxLDAuNjA2LDAuMDQ1LDEuMTIxLDAuMTg4\a\
LDEuNTYgICBjLTIuODQsNC41OTEtNS4xNjQsMi4xODktNi4zMTEsMC4zMTZjMC4yMTktMC41MDUs\a\
MC4zNTItMS4xMTgsMC4zMTItMS44NzZjMCwwLTEuODQtMS44NTgtMi4xMjEtNC4xMTQgICBjMCww\a\
LTAuMzU3LTAuNDc4LTAuNjM3LTEuNzI1YzAsMCwwLjg1NCw0LjM3NC0wLjcyNCw3Ljg0OGMtMS4y\a\
MjIsMC41MjQtMi40NTIsMC44OTYtMi40NTIsMC44OTYgICBjLTEuMzI4LDAuNTExLTEuODkxLDEu\a\
Mjc2LTEuODkxLDEuMjc2Yy0xLjk2MywyLjkxMi0yLjE5Myw5LjM5OC0yLjE5Myw5LjM5OGMwLjAy\a\
NiwxLjQ4MiwwLjY2MiwxLjYzNCwwLjY2MiwxLjYzNCAgIGM0LjUyMywyLjAxNiwxMS42MDcsMi4z\a\
NzUsMTEuNjA3LDIuMzc1YzcuMjc4LDAuMTU0LDEyLjU3NC0yLjA2OCwxMi41NzQtMi4wNjhjMC43\a\
Ny0wLjQ4NiwwLjc5My0wLjg2NywwLjc5My0wLjg2NyAgIEMyOC45NDMsMjMuNjY3LDI2LjY0Niwx\a\
OC40MzQsMjYuNjQ2LDE4LjQzNHoiLz4KCTxwYXRoIHN0eWxlPSJmaWxsOiMwMzAxMDQ7IiBkPSJN\a\
MTguODMzLDQuOTljMC4wNzgsMC4yOTEsMC41NDgsMS43ODMsMi4xMiwyLjQ1NWMwLDAsMC4wNTgt\a\
MC42MTEsMC4yMjktMC42NjkgICBjMCwwLDAuMTkzLDAuMDk2LDAuMjUsMC4zMjVjMCwwLDAuNDEt\a\
My45Mi0xLjM3NS01LjM4M2wwLjAxLTAuMDIxYy0zLjcyNi0zLjI4Ny03Ljk0Mi0wLjc4Ni03Ljk0\a\
Mi0wLjc4NiAgIGMtMy4wOSwxLjk4OC0yLjIyNiw2LjI4NC0yLjIyNiw2LjI4NEMxNS43MSw3Ljc0\a\
NCwxOC43NDUsNS4wNzEsMTguODMzLDQuOTl6Ii8+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+\a\
CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+Cjwv\a\
Zz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4K\a\
PC9zdmc+\a\
");
}
.contactImage.gender-m {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB2aWV3Qm94PSIwIDAgNDg3LjY3OCA0ODcuNjc4IiBzdHlsZT0iZW5hYmxlLWJh\a\
Y2tncm91bmQ6bmV3IDAgMCA0ODcuNjc4IDQ4Ny42Nzg7IiB4bWw6c3BhY2U9InByZXNlcnZlIj4K\a\
PGc+Cgk8Zz4KCQk8cGF0aCBzdHlsZT0iZmlsbDojMDEwMDAyOyIgZD0iTTM3Ny45OTYsMjgyLjM0\a\
N2MtNTYuMjAxLTE4LjM1Ny03OS41NjMtNDEuMTg1LTc5LjU2My00MS4xODVsLTEuODgxLDEuNzkz\a\
ICAgIGMtMTYuNjksMTUuNzA5LTM1LjE0OSwyNC45NDQtNTEuOTY1LDI0Ljk0NEgyNDNjLTE2Ljgx\a\
NSwwLTM1LjI3NC05LjIzNS01MS45NjQtMjQuOTQ0bC0xLjg4Mi0xLjc5MyAgICBjMCwwLTIzLjM2\a\
LDIyLjgyNy03OS41NjIsNDEuMTg1Yy04Mi45NjQsMzAuOTkyLTU4LjA1MywxNTcuMTE5LTU4LjA3\a\
NywxNTguMDk2YzIuNjEzLDE0LjA0Nyw0LjEzNiwxOC44NzUsNS40NjMsMTkuNDE3ICAgIGM4My4z\a\
MTQsMzcuMDkxLDI5MC4zMTksMzcuMDkxLDM3My42MzQsMGMxLjMyNy0wLjU0MiwyLjg1LTUuMzcs\a\
NS40NjMtMTkuNDE3QzQzNi4wNTEsNDM5LjQ2Niw0NjEuMjk1LDMxMy44NCwzNzcuOTk2LDI4Mi4z\a\
NDd6Ii8+CgkJPHBhdGggc3R5bGU9ImZpbGw6IzAxMDAwMjsiIGQ9Ik0zMzAuOTI0LDEyMS40NDFs\a\
LTAuNjk2LTAuNzU1Yy00LjY2OC00LjI3NC00LjMwMy00LjAyOS00LjMwMy00LjAyOXM4LjE0Mi00\a\
MS4wODMsMS42MTMtNjAuNTExICAgIGMtMTAuMjUtMzEuMDI3LTcxLjQ3NS01MS44MjItODMuNzU1\a\
LTU0LjIzOWMwLjAwMi0wLjAyMy03LjQ2OS0xLjUxOC03Ljk0Ni0xLjUyMWMwLDAtOS42NTktMS45\a\
NTMtMjAuODU0LDIuOTMgICAgYy03LjI5MSwyLjgwNS00NS40MDgsMjAuMDktNTYuMjI3LDUyLjgz\a\
Yy02LjUyOCwxOS40MjgsMS42MTQsNjAuNTExLDEuNjE0LDYwLjUxMXMwLjM2NS0wLjI0NS00LjMw\a\
NCw0LjAyOWwtMC42OTUsMC43NTUgICAgYy0zLjE1OCwzLjU4Ni0yLjM3OCwxNC44MDYsMS4wNzQs\a\
MjYuNDc5YzMuMTI4LDExLjY5NSw3LjIwNSwxNC44MzgsOC4xODIsMTcuNTc3YzkuOTAzLDQ2LjQ5\a\
Nyw0NC4zMzgsODYuMTk3LDc5LjQyOSw4Ni4xOTcgICAgczY3LjcwNy0zOS43LDc3LjYxLTg2LjE5\a\
N2MwLjk3OC0yLjczOCw1LjA1NS01Ljg4Miw4LjE4My0xNy41NzdDMzMzLjMwMSwxMzYuMjQ2LDMz\a\
NC4xNzIsMTI0LjI1NiwzMzAuOTI0LDEyMS40NDF6Ii8+Cgk8L2c+CjwvZz4KPGc+CjwvZz4KPGc+\a\
CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+Cjwv\a\
Zz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4KPGc+CjwvZz4K\a\
PGc+CjwvZz4KPC9zdmc+\a\
");
}
.contactImage.gender- {
  background-color: #f5f5f5;
  background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRw\a\
Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjEiIGlkPSJDYXBhXzEiIHg9IjBw\a\
eCIgeT0iMHB4IiB3aWR0aD0iNDc2LjUxOHB4IiBoZWlnaHQ9IjQ3Ni41MThweCIgdmlld0JveD0i\a\
MCAwIDQ3Ni41MTggNDc2LjUxOCIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgNDc2\a\
LjUxOCA0NzYuNTE4OyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+CjxnPgoJPHBhdGggZD0iTTI3Ni42\a\
MTksMzguMTE1Yy0yLjA0Ni0zLjE1OC0yLjcwMy01LjI5Mi0yLjcwMy01LjI5MmwwLjk3NS0wLjg5\a\
N2MwLDAsMS44OTYsMC43ODgsNS4yMSwyLjE0NiAgIGMxLjU2NCwwLjYyNCwzLjQ3OSwxLjM5LDUu\a\
Njc0LDIuMjU0YzIuMTYyLDAuNzgzLDQuNTE1LDEuNjk2LDcuMDM3LDIuMzA4YzEuMjQyLDAuMzg1\a\
LDIuNTA3LDAuNzY4LDMuODE0LDAuOTE1ICAgYzAuNjU4LDAuMDg3LDEuMjg1LDAuMjY4LDEuOTM3\a\
LDAuMzg4YzAuNjQ2LDAuMDQ0LDEuMjk0LDAuMDY1LDEuOTM4LDAuMTQ3YzIuNjA1LDAuMzUsNSww\a\
LjA2Nyw3LjYyNi0wLjA3ICAgYzEuMjE4LTAuNDQ4LDIuNTcyLTAuNTc0LDMuODk3LTEuMTQ0YzEu\a\
MjE0LTAuNzE3LDIuODAxLTEuMTMzLDMuOTI4LTIuMDUyYzAuNTk3LTAuNDEsMS4yMTctMC44Mzcs\a\
MS44ODItMS4yNTkgICBjMC42OS0wLjM4OCwxLjQyNC0wLjY5NSwyLjE1Ny0xLjQ4OGw0LjY0LTMu\a\
ODk2YzAuMDQ0LTAuMDYtMC4yNzEsMC4zOTktMC4xMiwwLjE4NWwwLjAzMi0wLjAzM2wwLjA3OS0w\a\
LjA3bDAuMTUzLTAuMTMxICAgbDAuMzA1LTAuMjczbDAuNjEyLTAuNTQ3bDEuMjE3LTEuMDY3bDIu\a\
Mjk3LTIuMTc4YzEuNDQ0LTEuNDg4LDMuMjYxLTIuNjQ4LDQuNzE3LTQuMDgyYzEuNDM0LTEuNDg0\a\
LDMuMzYxLTIuMzkyLDQuODk0LTMuODMxICAgYzEuNjQtMS4yOTIsMy41NTctMi4yNiw1LjQwNi0z\a\
LjUxM2MzLjg4NS0xLjgyOCw4LjQyNS0zLjE4NSwxMi40OS0yLjYxNWMxLjAxOSwwLjEwOSwyLjAw\a\
OSwwLjI2OCwyLjk4MywwLjQ0OCAgIGMwLjk0MiwwLjI2MiwxLjgyNywwLjU4NiwyLjcwMywwLjkx\a\
NGMxLjc5NCwwLjU5MiwzLjMzOSwxLjQzOSw0Ljc5NSwyLjI3NmMyLjkwOSwxLjY4MSw1LjIyMSwz\a\
LjYyOCw3LjA2OSw1LjUxMSAgIGMxLjgzNywxLjg4OCwzLjIxOCwzLjcyNyw0LjIxMiw1LjMzYzEu\a\
MDQyLDEuNTY5LDEuNjQ0LDIuOTU1LDIuMDY4LDMuOTAyYzAuMzUxLDAuOTc0LDAuNTM2LDEuNDk5\a\
LDAuNTM2LDEuNDk5bC0wLjk3NCwwLjkwOCAgIGMwLDAtMi4wODktMC43MDYtNS4yOTctMi4wNDdj\a\
LTEuNTYzLTAuNjIzLTMuNDU5LTEuNDA1LTUuNjM1LTIuMjgxYy0yLjEwMS0wLjg2NS00LjQxMi0x\a\
LjgxNy02Ljg1My0yLjY0MyAgIGMtMS4yMTUtMC40NDktMi40NzItMC45MTQtMy43NDItMS4yMjFj\a\
LTAuNjQ1LTAuMTU4LTEuMjc5LTAuNDExLTEuOTI3LTAuNTk2Yy0wLjY0Ni0wLjEzMS0xLjI5LTAu\a\
Mjk2LTEuOTM4LTAuNTA5ICAgYy0yLjYyMS0wLjg1NC01LjMyOS0xLjY5Ni04LjY4Mi0yLjA0NmMt\a\
MS41NCwwLjIwMy0zLjM3OSwwLjEzNy00Ljk4MSwwLjgwNWMtMS41NDEsMC43ODItMy4zMTEsMS4z\a\
ODQtNC41NDgsMi43NzQgICBjLTEuMjQ3LDEuMzQtMi42NywyLjUxMi0zLjU0NCw0LjIxOWwtMS4y\a\
NzEsMi41NDRsLTAuNTg0LDEuMjgxbC0wLjI4NCwwLjYzNWwtMC4xNCwwLjMyOGwtMC4wNywwLjE0\a\
N2wtMC4wMzMsMC4wNzdsLTAuMDIyLDAuMDQ5ICAgYzAuMTI2LTAuMTg2LTAuMTk2LDAuMjk2LTAu\a\
MTc0LDAuMjY4bC0yLjUwMSw1LjUxNmMtMC44MjEsMS43NzktMi43MDQsMy43ODctNC4yNDEsNS41\a\
NTRjLTEuNTYsMS45MjYtMy42NDksMy4wMzItNS41MDksNC41NDIgICBjLTEuOTQ3LDEuMzY4LTQu\a\
MzI0LDIuMTU2LTYuNSwzLjE0NmMtNC42MzEsMS4zMjMtOS40NjksMS41Ni0xMy41NCwwLjQ3MWMt\a\
Mi4wNzktMC40NTktMy45OTItMS4wNjItNS42NzgtMS45MzcgICBjLTEuNzY1LTAuNzQ1LTMuMjg2\a\
LTEuNjc0LTQuNzItMi41NzJjLTIuODUtMS44ODctNS4xMDktMy44ODUtNi44OTQtNS44NDRDMjc4\a\
Ljk3Myw0MS41NzMsMjc3LjYyMiwzOS43MDIsMjc2LjYxOSwzOC4xMTV6ICAgIE00NzYuNTE4LDM1\a\
MS4wM3YxMTMuNkgwdi0xMTMuNmgzMi40NTlWMjIzLjQybDkxLjQ3LTY0LjE3N3Y2NC4xNzdsOTEu\a\
NDU2LTY0LjE3N3Y2NC4xNzdsOTEuNDc1LTY0LjE3N3YxMjYuMTQzaDMxLjU2ICAgbDE3LjE0LTIy\a\
My4xMzloNTIuMzEzbDE1LjAwMiwyMjMuMTM5aDM1LjE5NnY2NS42NTNoMTguNDQ2VjM1MS4wM3og\a\
TTE0OS4zNzUsMzAxLjk3NUg3Ny40NjF2NjYuMzg3aDcxLjkxNFYzMDEuOTc1eiAgICBNMjczLjI5\a\
MywzMDEuOTc1aC03MS45MTZ2NjYuMzg3aDcxLjkxNlYzMDEuOTc1eiBNMzk4Ljc2OCwzMDEuOTc1\a\
aC03MS45MTR2NjYuMzg3aDcxLjkxNFYzMDEuOTc1eiIvPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+\a\
CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+Cjxn\a\
Pgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8L2c+CjxnPgo8\a\
L2c+Cjwvc3ZnPg==\a\
");
}

.contact-placeholder {
  padding-bottom: 100%;
}
.contactInfo {
  list-style-type: none;
  margin: 0;
  padding: 0;
  zoom: 1;
  margin-bottom: 1.414em;
}
.contactInfo:before, .contactInfo:after {
  content: " ";
  display: block;
  height: 0;
  visibility: hidden;
}
.contactInfo:after {
  clear: both;
}
.contactInfo > li {
  display: block;
}
.contactInfo > li > a {
  display: block;
  padding: 0.7em 1.2em;
}
.contact-links {
  margin: 0;
}
.contact-links dd {
  margin: 0;
}
.contact-links > dt {
  text-align: left;
  float: left;
  clear: left;
}
.contact-links > dd {
  overflow: hidden;
  text-overflow: ellipsis;
}
.contact-links > dt {
  font-size: 1.2rem;
  min-width: 2.4rem;
}
.contact-links > dt:before {
  display: inline !important;
}
#contact-phone-mobile {
  font-size: 1.728rem;
}
